@@ -2,62 +2,115 @@
 # -*- coding: UTF-8 -*-
 import requests
 import json
+# import curlify
 
+from litncov import muyunhost
 from litncov import endpoints
 from litncov import identitys
 from litncov import util
 
 
+
 class litUesr:
     """lit uesr object"""
 
     def __init__(self, username: str, password: str):
+        self.session = requests.Session()
         self.username = username
         self.password = util.get_sha256(password)
 
         self.__headers = {
-            "Connection": "keep-alive",
-            "Content-Type": "application/json",
-            "User-Agent": "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.212 Safari/537.36",
+            'Proxy-Connection': 'keep-alive',
+            'Accept': 'application/json, text/plain, */*',
+            'DNT': '1',
+            'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.114 Safari/537.36',
+            'Content-Type': 'application/json;charset=UTF-8;Access-Control-Allow-Headers',
+            'Origin': 'http://hmgr.sec.lit.edu.cn',
+            'Referer': 'http://hmgr.sec.lit.edu.cn/web/',
+            'Accept-Language': 'zh-CN,zh;q=0.9',
         }
 
-        # login the acconut
+
+        # self.__cookies = {
+        #    # "muyun_sign_cookie": "7034bbc44c88bcb8781dae8af9e474ca"
+        # }
+
+        self.proxies = None
+
+        #login the acconut
         try:
+            # self.__set_cookies()
             self.login = self.__login()
         except:
             self.info = None
 
-        # get the user info
+        # init last record info
+        self.last_record = None
+
+    def __set_cookies(self):
         try:
-            self.info = self.login["data"]
+            self.session.head(
+                url=muyunhost, timeout=5, headers=self.__headers
+            )
+
+            # self.__cookies = response.cookies
+        except:
+            pass
+
+        # print(response.text)
+
+        return
+
+    def is_logged(self):
+        try:
+            if self.get_last_record()['code'] == 200:
+                return True
+            else:
+                return False
+        except:
+            return False
+
+    def __login(self):
+
+        self.__set_cookies()
+
+        data = {"cardNo": self.username, "password": self.password}
+
+
+        #login func
+        try:
+            response =self.session.post(
+                url=endpoints["login"], data=json.dumps(data), headers=self.__headers, timeout=5,verify=False
+            )
+
+            print(response.text)
+
+            # print(curlify.to_curl(response.request))
+        # get the user info
+        
+
+        except:
+            return None
+
+        # print(response.text)
+        res = response.json()
+
+        try:
+            self.info = res["data"]
         except:
             self.info = None
 
         # update some values
         try:
             self.__headers["token"] = self.info["token"]
-            self.is_logged = True
+            
         except:
-            self.is_logged = False
+            pass
 
-        # init last record info
-        self.last_record = None
 
-    def __login(self):
-        data = {"cardNo": self.username, "password": self.password}
-
-        # login func
-        try:
-            response = requests.post(
-                url=endpoints["login"], data=json.dumps(data), headers=self.__headers, timeout=5
-            )
-        except:
-            return None
-
-        res = response.json()
 
         return res
-    
+
     def relogin(self):
         # login the acconut
         try:
@@ -65,11 +118,26 @@ class litUesr:
         except:
             self.info = None
 
+    def set_proxy(self, proxy_url):
+        proxies = {
+            "http": proxy_url,
+            "https": proxy_url,
+        }
+
+        self.session.proxies.update(proxies)
+
+        # login the acconut
+        try:
+            self.login = self.__login()
+        except:
+            self.info = None
+        return
+
     def get_last_record(self):
         data = {"teamId": self.info["teamId"], "userId": self.info["userId"]}
 
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["lastRecord"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -98,10 +166,12 @@ class litUesr:
 
             if rtime == 1:
                 return True
-            elif (rtime == 2) & (self.last_record["temperatureTwo"] != ""):
+            elif (rtime == 2) and (self.last_record["temperatureTwo"] != "" and self.last_record["temperatureTwo"] != None):
                 return True
-            elif (rtime == 3) & (self.last_record["temperatureThree"] != ""):
+            elif (rtime == 3) and (self.last_record["temperatureThree"] != "" and self.last_record["temperatureTwo"] != None ):
                 return True
+            else:
+                return False
         else:
             return False
 
@@ -113,7 +183,7 @@ class litUesr:
         }
 
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["getInstructor"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -129,7 +199,7 @@ class litUesr:
         }
 
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["getFamilys"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -141,7 +211,7 @@ class litUesr:
 
     def get_important_city(self):
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["getImportantCity"], headers=self.__headers, timeout=5
             )
         except:
@@ -157,7 +227,7 @@ class litUesr:
         }
 
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["getTrips"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -173,7 +243,7 @@ class litUesr:
         }
 
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["isInTeamCityCount"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -189,7 +259,7 @@ class litUesr:
         }
 
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["countUnHealthy"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -212,7 +282,7 @@ class litUesr:
         }
 
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["reportCount"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -229,7 +299,7 @@ class litUesr:
         }
 
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["accessCertificateCount"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -250,7 +320,7 @@ class litUesr:
         }
 
         try:
-            response = requests.get(
+            response = self.session.get(
                 url=endpoints["queryRecord"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -424,7 +494,7 @@ class litUesr:
             print("Warning: Incorrect temperatureThree!")
 
         try:
-            response = requests.post(
+            response = self.session.post(
                 url=endpoints["firstRecord"],
                 data=json.dumps(data),
                 headers=self.__headers, timeout=5,
@@ -469,7 +539,7 @@ class litUesr:
             print("Warning: Incorrect temperatureTwo!")
 
         try:
-            response = requests.put(
+            response = self.session.put(
                 url=endpoints["secondRecord"], params=data, headers=self.__headers, timeout=5
             )
         except:
@@ -525,7 +595,7 @@ class litUesr:
         data = {"password": util.get_sha256(psw)}
 
         try:
-            response = requests.put(
+            response = self.session.put(
                 url=endpoints["password"], params=data, headers=self.__headers, timeout=5
             )
         except:
