@@ -3,7 +3,6 @@ import hashlib
 import pytz
 import time
 import datetime
-import gb2260
 import random
 
 
@@ -62,30 +61,6 @@ def is_valid_date(strdate):
 #     return int(ts)
 
 
-def cl_build(current_district):
-    """ use gb2260 to build a CurrentLocation """
-    div_result = []
-    try:
-        division = gb2260.get(current_district)
-        for current in division.stack():
-            temp = str(u"{0}".format(current.name))
-            div_result.append(temp)
-            # use "-" to split str
-        return "-".join(str(i) for i in div_result)
-    except:
-        return None
-
-
-def current_location(currentDistrict, currentCity):
-    """ is not grace :( """
-    cl = cl_build(currentDistrict)
-    if cl == None:
-        cl = cl_build(currentCity)
-    if cl == None:
-        return None
-    return cl
-
-
 def random_temp():
     """ build a random temp """
-    return round(random.uniform(36.0, 37.2), 2)
+    return round(random.uniform(36.0, 37.0), 1)
